@@ -530,8 +530,7 @@ If there are no timers, throw an error."
 
 (defun tmr-notification-notify (timer)
   "Dispatch a notification for TIMER.
-
-Read: (info \"(elisp) Desktop Notifications\") for details."
+Read Info node `(elisp) Desktop Notifications' for details."
   (if (featurep 'dbusbind)
       (let ((title "TMR May Ring (Emacs tmr package)")
             (body (tmr--long-description-for-finished-timer timer)))
@@ -919,7 +918,7 @@ they are set to reasonable default values."
 (defun tmr-mode-line--format-remaining (timer)
   "Format remaining time for TIMER with appropriate face."
   (let* ((secs (float-time (time-subtract (tmr--timer-end-date timer) nil)))
-         (face (cond ((and (< secs 5) (evenp (truncate secs)))
+         (face (cond ((and (< secs 5) (= (% (truncate secs) 2) 0))
                       '(tmr-mode-line-urgent (:inverse-video t)))
                      ((< secs 30) 'tmr-mode-line-urgent)
                      ((= (truncate secs) 30)
@@ -969,7 +968,7 @@ they are set to reasonable default values."
                (seq-sort-by #'tmr--timer-end-date #'time-less-p)))
 
 (defun tmr-mode-line--update ()
-  "Updates `tmr-mode-line-string' based on the current timer state."
+  "Update `tmr-mode-line-string' based on the current timer state."
   (setq
    tmr-mode-line-string
    (if-let* ((active-timers (tmr-mode-line--get-active-timers)))
